@@ -12,7 +12,7 @@ __author__ = 'Jens Finkhaeuser'
 __copyright__ = 'Copyright (c) 2016-2018 Jens Finkhaeuser'
 __license__ = 'MIT +no-false-attribs'
 __all__ = ('util', 'mixins', 'cli', 'convert')
-__version__ = '0.16.0'
+__version__ = '0.17.0'
 
 
 # Define our own error class
@@ -65,6 +65,8 @@ class BaseParser(mixins.YAMLMixin, mixins.JSONMixin, object):
     :param bool strict: [optional] Applies only to the 'swagger-spec-validator'
       backend. If False, accepts non-String keys by stringifying them before
       validation. Defaults to True.
+    :param str encoding: [optional] For local URLs, use the given file encoding
+      instead of auto-detecting. Defaults to None.
     """
     assert url or spec_string and not (url and spec_string), \
         'You must provide either a URL to read, or a spec string to '\
@@ -114,7 +116,8 @@ class BaseParser(mixins.YAMLMixin, mixins.JSONMixin, object):
     # If we have a file name, we need to read that in.
     if self.url and self.url != _PLACEHOLDER_URL:
       from .util.url import fetch_url
-      self.specification = fetch_url(self.url)
+      encoding = self.options.get('encoding', None)
+      self.specification = fetch_url(self.url, encoding = encoding)
 
     # If we have a spec string, try to parse it.
     if self._spec_string:
@@ -135,10 +138,7 @@ class BaseParser(mixins.YAMLMixin, mixins.JSONMixin, object):
 
   def _validate(self):
     # Ensure specification is a mapping
-    try:
-      from collections.abc import Mapping
-    except ImportError:  # Python 2
-      from collections import Mapping
+    from collections.abc import Mapping
     if not isinstance(self.specification, Mapping):
       raise ValidationError('Could not parse specifications!')
 
@@ -183,7 +183,7 @@ class BaseParser(mixins.YAMLMixin, mixins.JSONMixin, object):
       stringified = '%d.%d' % (version[0], version[1])
     self.version = '%s %s' % (self.version_name, stringified)
 
-  def _validate_flex(self, spec_version):
+  def _validate_flex(self, spec_version):  # pragma: nocover
     # Set the version independently of whether validation succeeds
     self.__set_version(BaseParser.SPEC_VERSION_2_PREFIX, spec_version)
 
@@ -267,7 +267,8 @@ class ResolvingParser(BaseParser):
     # http://swagger.io/specification/#referenceObject
     # We therefore use our own resolver first, and validate later.
     from .util.resolver import RefResolver
-    resolver = RefResolver(self.specification, self.url)
+    encoding = self.options.get('encoding', None)
+    resolver = RefResolver(self.specification, self.url, encoding = encoding)
     resolver.resolve_references()
     self.specification = resolver.specs
 
